==> flutter_payumoney_plugin-0.0.18.tar.gz: ios/Classes/SwiftFlutterPayumoneyPlugin.swift <==
import Flutter
import UIKit

public class SwiftFlutterPayumoneyPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "flutter_payumoney_plugin", binaryMessenger: registrar.messenger())
        let instance = SwiftFlutterPayumoneyPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        }
        else if (call.method == "payUmoneyPayment") {
            //result("\(checkiOSReturn())")
            if let topVC = UIApplication.shared.windows[0].rootViewController {
                
                guard let args = call.arguments else {
                    return
                }
                if let myArgs = args as? [String: Any], let amountVal = myArgs["amount"] as? String, let nameVal = myArgs["UserName"] as? String, let emailVal = myArgs["email"] as? String, let mobileVal = myArgs["mobile"] as? String, let formName = myArgs["formName"], let gNumber = myArgs["gNumber"], let isProductionVal = myArgs["environmentMode"] as? Int {
                    startPaymentWithAmount(amountVal, userName: nameVal, email: emailVal, contactNo: mobileVal, formName: formName, gNumber: gNumber, isProduction: isProductionVal == 1, fromController: topVC) { (response, transactionID, error) in
                        result(transactionID)
                    }
                }
            }
        }
        else {
            result("Failed to get top controller")
        }
    }
}

==> flutter_payumoney_plugin-0.0.19.tar.gz: ios/Classes/SwiftFlutterPayumoneyPlugin.swift <==
import Flutter
import UIKit

public class SwiftFlutterPayumoneyPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "flutter_payumoney_plugin", binaryMessenger: registrar.messenger())
        let instance = SwiftFlutterPayumoneyPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        }
        else if (call.method == "payUmoneyPayment") {
            //result("\(checkiOSReturn())")
            if let topVC = UIApplication.shared.windows[0].rootViewController {
                
                guard let args = call.arguments else {
                    return
                }
                if let myArgs = args as? [String: Any], let amountVal = myArgs["amount"] as? String, let nameVal = myArgs["UserName"] as? String, let emailVal = myArgs["email"] as? String, let mobileVal = myArgs["mobile"] as? String, let formName = myArgs["formName"] as? String, let gNumber = myArgs["gNumber"] as? String, let isProductionVal = myArgs["environmentMode"] as? Int {
                    startPaymentWithAmount(amountVal, userName: nameVal, email: emailVal, contactNo: mobileVal, formName: formName, gNumber: gNumber, isProduction: isProductionVal == 1, fromController: topVC) { (response, transactionID, error) in
                        result(transactionID)
                    }
                }
            }
        }
        else {
            result("Failed to get top controller")
        }
    }
}
